@@ -383,6 +383,31 @@ void tool_show_progress(const gchar *file, const struct mega_status_data *data)
 	last_bytes = now_done;
 }
 
+gchar* tool_prompt_input(void)
+{
+	gc_string_free GString* str = g_string_sized_new(1024);
+	gchar* ret = NULL;
+
+	while (TRUE) {
+		char buf[256];
+
+		if (fgets(buf, sizeof buf, stdin) == NULL)
+			return NULL;
+
+		int len = strlen(buf);
+		gboolean has_eol = buf[len - 1] == '\n';
+		if (len > 0)
+			g_string_append_len(str, buf, has_eol ? len - 1 : len);
+
+		if (has_eol || feof(stdin))
+			break;
+	}
+
+	ret = g_string_free(str, FALSE);
+	str = NULL;
+	return ret;
+}
+
 static gchar *input_password(void)
 {
 	gint tries = 3;
@@ -464,6 +489,13 @@ gchar *tool_convert_filename(const gchar *path, gboolean local)
 	return locale_path;
 }
 
+static void fix_options(GOptionEntry* list)
+{
+	for (int i = 0; list[i].long_name; i++) {
+		list[i].flags |= G_OPTION_FLAG_IN_MAIN;
+	}
+}
+
 void tool_init(gint *ac, gchar ***av, const gchar *tool_name, GOptionEntry *tool_entries, ToolInitFlags flags)
 {
 	GError *local_err = NULL;
@@ -474,25 +506,10 @@ void tool_init(gint *ac, gchar ***av, const gchar *tool_name, GOptionEntry *tool
 	if (tool_entries)
 		g_option_context_add_main_entries(opt_context, tool_entries, NULL);
 
-	GOptionGroup *basic_group = g_option_group_new("basic", "Basic Options:", "Show basic options", NULL, NULL);
-	g_option_group_add_entries(basic_group, basic_options);
-	g_option_context_add_group(opt_context, basic_group);
-
-	GOptionGroup *network_group =
-		g_option_group_new("network", "Network Options:", "Show network options", NULL, NULL);
-	g_option_group_add_entries(network_group, network_options);
-	g_option_context_add_group(opt_context, network_group);
-
-	if (flags & (TOOL_INIT_AUTH | TOOL_INIT_AUTH_OPTIONAL)) {
-		GOptionGroup *auth_group = g_option_group_new(
-			"auth", "Authentication Options:", "Show authentication options", NULL, NULL);
-		g_option_group_add_entries(auth_group, auth_options);
-		g_option_context_add_group(opt_context, auth_group);
-	}
-
 	if (flags & TOOL_INIT_UPLOAD_OPTS) {
 		GOptionGroup *upload_group =
 			g_option_group_new("upload", "Upload Options:", "Show upload options", NULL, NULL);
+		fix_options(upload_options);
 		g_option_group_add_entries(upload_group, upload_options);
 		g_option_context_add_group(opt_context, upload_group);
 	}
@@ -500,10 +517,30 @@ void tool_init(gint *ac, gchar ***av, const gchar *tool_name, GOptionEntry *tool
 	if (flags & TOOL_INIT_DOWNLOAD_OPTS) {
 		GOptionGroup *download_group =
 			g_option_group_new("download", "Dwonload Options:", "Show download options", NULL, NULL);
+		fix_options(download_options);
 		g_option_group_add_entries(download_group, download_options);
 		g_option_context_add_group(opt_context, download_group);
 	}
 
+	if (flags & (TOOL_INIT_AUTH | TOOL_INIT_AUTH_OPTIONAL)) {
+		GOptionGroup *auth_group = g_option_group_new(
+			"auth", "Authentication Options:", "Show authentication options", NULL, NULL);
+		fix_options(auth_options);
+		g_option_group_add_entries(auth_group, auth_options);
+		g_option_context_add_group(opt_context, auth_group);
+	}
+
+	GOptionGroup *network_group =
+		g_option_group_new("network", "Network Options:", "Show network options", NULL, NULL);
+	fix_options(network_options);
+	g_option_group_add_entries(network_group, network_options);
+	g_option_context_add_group(opt_context, network_group);
+
+	GOptionGroup *basic_group = g_option_group_new("basic", "Basic Options:", "Show basic options", NULL, NULL);
+	fix_options(basic_options);
+	g_option_group_add_entries(basic_group, basic_options);
+	g_option_context_add_group(opt_context, basic_group);
+
 	if (!g_option_context_parse(opt_context, ac, av, &local_err)) {
 		g_printerr("ERROR: Option parsing failed: %s\n", local_err->message);
 		g_clear_error(&local_err);
